@@ -46,20 +46,20 @@ namespace BOOM{
     typedef Ptr<Variable> VarPtr;
     VsSuf();
     VsSuf(const VsSuf &rhs);
-    VsSuf * clone()const;
-    void clear();
-    void Update(const GlmCoefs &);
+    VsSuf * clone()const override;
+    void clear() override;
+    void Update(const GlmCoefs &) override;
     void add_var(VarPtr v);
     void combine(Ptr<VsSuf>);
     void combine(const VsSuf &);
-    VsSuf * abstract_combine(Sufstat *s);
+    VsSuf * abstract_combine(Sufstat *s) override;
 
-    virtual Vec vectorize(bool minimal=true)const;
-    virtual Vec::const_iterator unvectorize(Vec::const_iterator &v,
-                                            bool minimal=true);
-    virtual Vec::const_iterator unvectorize(const Vec &v,
-                                            bool minimal=true);
-    virtual ostream &print(ostream &out)const;
+    Vector vectorize(bool minimal=true)const override;
+    Vector::const_iterator unvectorize(Vector::const_iterator &v,
+                                            bool minimal=true) override;
+    Vector::const_iterator unvectorize(const Vector &v,
+                                            bool minimal=true) override;
+    ostream &print(ostream &out)const override;
   private:
     std::vector<VarPtr> vars_;
   };
@@ -79,9 +79,9 @@ namespace BOOM{
   public:
     VariableSelectionPrior();
     VariableSelectionPrior(uint n, double pi=1.0);
-    VariableSelectionPrior(const Vec &pi);
+    VariableSelectionPrior(const Vector &pi);
     VariableSelectionPrior(const VariableSelectionPrior &rhs);
-    VariableSelectionPrior * clone()const;
+    VariableSelectionPrior * clone()const override;
 
     //    double loglike()const;
     virtual void mle();
@@ -110,12 +110,18 @@ namespace BOOM{
     // its parents are also present.  If any of its parents are absent
     // then the interaction has inclusion probability 0.
 
+    // TODO(stevescott): This class needs to be split apart.  The bit
+    // about interactions and main effects (which are dependent on one
+    // another) is at odds with the notion that there is a vector of
+    // prior inclusion probabilities (which implies independence).
+    // Most instances of this class assume the independence case.
+    Vector prior_inclusion_probabilities() const;
     double prob(uint i)const;
-    void set_probs(const Vec & pi);
+    void set_probs(const Vector & pi);
     void set_prob(double prob, uint i);
-    ParamVec t();
-    const ParamVec t()const;
-    virtual void unvectorize_params(const Vec &v, bool minimal=true);
+    ParamVector t() override;
+    const ParamVector t()const override;
+    void unvectorize_params(const Vector &v, bool minimal=true) override;
 
     ostream & print(ostream & out)const;
 
