@@ -35,34 +35,34 @@ namespace BOOM{
   public:
     WeightedMvnSuf(uint p);
     WeightedMvnSuf(const WeightedMvnSuf &rhs);
-    WeightedMvnSuf * clone()const;
+    WeightedMvnSuf * clone()const override;
 
-    void clear();
-    void Update(const WeightedVectorData &x);
+    void clear() override;
+    void Update(const WeightedVectorData &x) override;
 
-    const Vec & sum()const;
-    const Spd & sumsq()const;
+    const Vector & sum()const;
+    const SpdMatrix & sumsq()const;
     double n()const;
     double sumw()const;
     double sumlogw()const;
 
-    Vec ybar()const;
-    Spd var_hat()const;
-    Spd center_sumsq(const Vec &mu)const;
-    Spd center_sumsq()const;
+    Vector ybar()const;
+    SpdMatrix var_hat()const;
+    SpdMatrix center_sumsq(const Vector &mu)const;
+    SpdMatrix center_sumsq()const;
     void combine(Ptr<WeightedMvnSuf>);
     void combine(const WeightedMvnSuf &);
-    WeightedMvnSuf * abstract_combine(Sufstat *s);
+    WeightedMvnSuf * abstract_combine(Sufstat *s) override;
 
-    virtual Vec vectorize(bool minimal=true)const;
-    virtual Vec::const_iterator unvectorize(Vec::const_iterator &v,
-					    bool minimal=true);
-    virtual Vec::const_iterator unvectorize(const Vec &v,
-					    bool minimal=true);
-    virtual ostream &print(ostream &out)const;
+    Vector vectorize(bool minimal=true)const override;
+    Vector::const_iterator unvectorize(Vector::const_iterator &v,
+					    bool minimal=true) override;
+    Vector::const_iterator unvectorize(const Vector &v,
+					    bool minimal=true) override;
+    ostream &print(ostream &out)const override;
   private:
-    Vec sum_;
-    Spd sumsq_;
+    Vector sum_;
+    SpdMatrix sumsq_;
     double n_;
     double sumw_;
     double sumlogw_;
@@ -76,9 +76,9 @@ namespace BOOM{
   {
   public:
     WeightedMvnModel(uint p, double mu=0.0, double sig=1.0);
-    WeightedMvnModel(const Vec &mean, const Spd &Var); // N(mu, Var)
+    WeightedMvnModel(const Vector &mean, const SpdMatrix &Var); // N(mu, Var)
     WeightedMvnModel(const WeightedMvnModel &m);
-    WeightedMvnModel *clone() const;
+    WeightedMvnModel *clone() const override;
 
     Ptr<VectorParams> Mu_prm();
     const Ptr<VectorParams> Mu_prm()const;
@@ -86,16 +86,16 @@ namespace BOOM{
     const Ptr<SpdParams> Sigma_prm()const;
 
     int dim() const {return mu().size();}
-    const Vec & mu() const;
-    const Spd & Sigma()const;
-    const Spd & siginv() const;
+    const Vector & mu() const;
+    const SpdMatrix & Sigma()const;
+    const SpdMatrix & siginv() const;
     double ldsi()const;
 
-    void set_mu(const Vec &);
-    void set_Sigma(const Spd &);
-    void set_siginv(const Spd &);
-    void mle();
-    double loglike(const Vector &mu_siginv_triangle) const;
+    void set_mu(const Vector &);
+    void set_Sigma(const SpdMatrix &);
+    void set_siginv(const SpdMatrix &);
+    void mle() override;
+    double loglike(const Vector &mu_siginv_triangle) const override;
 
     double pdf(Ptr<Data>, bool logscale)const;
     double pdf(Ptr<DataType>, bool logscale)const;
