@@ -19,7 +19,6 @@
 #include <Models/Glm/RegressionModel.hpp>
 #include <LinAlg/Types.hpp>
 #include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <Models/Glm/PosteriorSamplers/RegressionConjSampler.hpp>
 #include <Models/GammaModel.hpp>
 #include <Models/Glm/MvnGivenXandSigma.hpp>
 #include <sstream>
@@ -63,7 +62,7 @@ namespace BOOM{
     if (inc.nvars() == 0) {
       return ans;
     }
-    const Spd xtx(this->xtx(inc));
+    const SpdMatrix xtx(this->xtx(inc));
     const Vector xty(this->xty(inc));
     const Vector beta(coefficients.included_coefficients());
     ans += beta.dot(xtx * beta) - 2 * beta.dot(xty);
@@ -131,7 +130,7 @@ namespace BOOM{
     //    if(!current) refresh_qr();
     return Qty.size();}
 
-  Spd QrRegSuf::xtx()const{
+  SpdMatrix QrRegSuf::xtx()const{
     //    if(!current) refresh_qr();
     return RTR(qr.getR());}
 
@@ -139,7 +138,7 @@ namespace BOOM{
     //    if(!current) refresh_qr();
     return Qty*qr.getR(); }
 
-  Spd QrRegSuf::xtx(const Selector &inc)const{
+  SpdMatrix QrRegSuf::xtx(const Selector &inc)const{
     //    if(!current) refresh_qr();
     return inc.select(xtx());
   }
@@ -153,7 +152,7 @@ namespace BOOM{
   void QrRegSuf::clear(){
     sumsqy = 0;
     Qty = 0;
-    qr = QR(Spd(Qty.size(), 0.0));
+    qr = QR(SpdMatrix(Qty.size(), 0.0));
   }
 
   QrRegSuf * QrRegSuf::clone()const{
@@ -250,7 +249,7 @@ namespace BOOM{
     return ans;
   }
 
-  Vec::const_iterator QrRegSuf::unvectorize(Vec::const_iterator &v,
+  Vector::const_iterator QrRegSuf::unvectorize(Vector::const_iterator &v,
                                   bool){
     const double *dp = &(*v);
     const double *original = dp;
@@ -265,8 +264,8 @@ namespace BOOM{
     return v;
   }
 
-  Vec::const_iterator QrRegSuf::unvectorize(const Vector &v, bool minimal){
-    Vec::const_iterator it(v.begin());
+  Vector::const_iterator QrRegSuf::unvectorize(const Vector &v, bool minimal){
+    Vector::const_iterator it(v.begin());
     return unvectorize(it, minimal);
   }
 
@@ -300,7 +299,7 @@ namespace BOOM{
     sumsqy = y.dot(y);
   }
 
-  NeRegSuf::NeRegSuf(const Spd & XTX,
+  NeRegSuf::NeRegSuf(const SpdMatrix & XTX,
                      const Vector & XTY,
                      double YTY,
                      double n,
@@ -347,8 +346,8 @@ namespace BOOM{
     ++n_;
     int p = rdp.xdim();
     if(xtx_.nrow()==0 || xtx_.ncol()==0)
-      xtx_ = Spd(p,0.0);
-    if(xty_.size()==0) xty_ = Vec(p, 0.0);
+      xtx_ = SpdMatrix(p,0.0);
+    if(xty_.size()==0) xty_ = Vector(p, 0.0);
     const Vector & tmpx(rdp.x());  // add_intercept(rdp.x());
     double y = rdp.y();
     xty_.axpy(tmpx, y);
@@ -362,13 +361,13 @@ namespace BOOM{
   }
 
   uint NeRegSuf::size()const{ return xtx_.ncol();}  // dim(beta)
-  Spd NeRegSuf::xtx()const{
+  SpdMatrix NeRegSuf::xtx()const{
     reflect();
     return xtx_;
   }
   Vector NeRegSuf::xty()const{ return xty_;}
 
-  Spd NeRegSuf::xtx(const Selector &inc)const{
+  SpdMatrix NeRegSuf::xtx(const Selector &inc)const{
     reflect();
     return inc.select(xtx_);
   }
@@ -382,7 +381,7 @@ namespace BOOM{
   }
 
   double NeRegSuf::SSE()const{
-    Spd ivar = xtx().inv();
+    SpdMatrix ivar = xtx().inv();
     return yty() - ivar.Mdist(xty()); }
   double NeRegSuf::SST()const{ return sumsqy - n()*pow(ybar(),2); }
   double NeRegSuf::n()const{ return n_; }
@@ -424,7 +423,7 @@ namespace BOOM{
     return ans;
   }
 
-  Vec::const_iterator NeRegSuf::unvectorize(Vec::const_iterator &v,
+  Vector::const_iterator NeRegSuf::unvectorize(Vector::const_iterator &v,
                                   bool minimal){
     // do we want to store xtx_is_fixed_?
     xtx_.unvectorize(v, minimal);
@@ -438,9 +437,9 @@ namespace BOOM{
     return v;
   }
 
-  Vec::const_iterator NeRegSuf::unvectorize(const Vector &v, bool minimal){
+  Vector::const_iterator NeRegSuf::unvectorize(const Vector &v, bool minimal){
     // do we want to store xtx_is_fixed_?
-    Vec::const_iterator it = v.begin();
+    Vector::const_iterator it = v.begin();
     return unvectorize(it, minimal);
   }
 
@@ -492,22 +491,25 @@ namespace BOOM{
   RM::RegressionModel(uint p)
     : GlmModel(),
       ParamPolicy(new GlmCoefs(p), new UnivParams(1.0)),
-      DataPolicy(new NeRegSuf(p)),
-      ConjPriorPolicy()
+      DataPolicy(new NeRegSuf(p))
   {}
 
   RM::RegressionModel(const Vector &b, double Sigma)
     : GlmModel(),
       ParamPolicy(new GlmCoefs(b), new UnivParams(Sigma*Sigma)),
-      DataPolicy(new NeRegSuf(b.size())),
-      ConjPriorPolicy()
+      DataPolicy(new NeRegSuf(b.size()))
+  {}
+
+  RM::RegressionModel(Ptr<GlmCoefs> beta, Ptr<UnivParams> sigsq)
+    : GlmModel(),
+      ParamPolicy(beta, sigsq),
+      DataPolicy(new NeRegSuf(beta->nvars_possible()))
   {}
 
   RM::RegressionModel(const Matrix &X, const Vector &y)
     : GlmModel(),
       ParamPolicy(new GlmCoefs(X.ncol()), new UnivParams(1.0)),
-      DataPolicy(new QrRegSuf(X,y)),
-      ConjPriorPolicy()
+      DataPolicy(new QrRegSuf(X,y))
   {
     mle();
   }
@@ -516,8 +518,7 @@ namespace BOOM{
     : GlmModel(),
       ParamPolicy(new GlmCoefs(d[0]->xdim(), include_all_variable),
                   new UnivParams(1.0)),
-      DataPolicy(new NeRegSuf(d.begin(), d.end())),
-      ConjPriorPolicy()
+      DataPolicy(new NeRegSuf(d.begin(), d.end()))
   {}
 
   RM::RegressionModel(const RegressionModel &rhs)
@@ -525,7 +526,7 @@ namespace BOOM{
       GlmModel(rhs),
       ParamPolicy(rhs),
       DataPolicy(rhs),
-      ConjPriorPolicy(rhs),
+      PriorPolicy(rhs),
       NumOptModel(rhs),
       EmMixtureComponent(rhs)
   {}
@@ -535,10 +536,10 @@ namespace BOOM{
   uint RM::nvars()const{ return coef().nvars(); }
   uint RM::nvars_possible()const{ return coef().nvars_possible(); }
 
-  Spd RM::xtx(const Selector &inc)const{ return suf()->xtx(inc);}
+  SpdMatrix RM::xtx(const Selector &inc)const{ return suf()->xtx(inc);}
   Vector RM::xty(const Selector &inc)const{ return suf()->xty(inc);}
 
-  Spd RM::xtx()const{ return xtx( coef().inc() ) ;}
+  SpdMatrix RM::xtx()const{ return xtx( coef().inc() ) ;}
   Vector RM::xty()const{ return xty( coef().inc() ) ;}
   double RM::yty()const{ return suf()->yty();  }
 
@@ -578,8 +579,8 @@ namespace BOOM{
   void RM::make_X_y(Matrix &X, Vector &Y)const{
     uint p = xdim();
     uint n = dat().size();
-    X = Mat(n,p);
-    Y = Vec(n);
+    X = Matrix(n,p);
+    Y = Vector(n);
     for(uint i=0; i<n; ++i){
       Ptr<RegressionData> rdp = dat()[i];
       const Vector &x(rdp->x());
@@ -618,7 +619,7 @@ namespace BOOM{
     double ans =  -.5*(n * log2pi  + n *log(sigsq)+ SSE/sigsq);
 
     if(nd>0){  // sigsq derivs come first in CP2 vectorization
-      Spd xtx = this->xtx();
+      SpdMatrix xtx = this->xtx();
       Vector gbeta = (xty() - xtx*b)/sigsq;
       double sig4 = sigsq*sigsq;
       double gsigsq = -n/(2*sigsq) + SSE/(2*sig4);
@@ -660,15 +661,6 @@ namespace BOOM{
     reset_suf_ptr(ne_reg_suf);
   }
 
-  void RM::set_conjugate_prior(Ptr<MvnGivenXandSigma> b, Ptr<GammaModel> siginv){
-    NEW(RegressionConjSampler, pri)(this, b,siginv);
-    this->set_conjugate_prior(pri);
-  }
-
-  void RM::set_conjugate_prior(Ptr<RegressionConjSampler> pri){
-    ConjPriorPolicy::set_conjugate_prior(pri);
-  }
-
   void RM::add_mixture_data(Ptr<Data> dp, double prob){
     Ptr<RegressionData> d(DAT(dp));
     suf()->add_mixture_data(d->y(), d->x(), prob);
