@@ -21,6 +21,7 @@
 #include <Models/IRT/Subject.hpp>
 #include <cpputil/seq.hpp>
 #include <cpputil/lse.hpp>
+#include <cpputil/report_error.hpp>
 #include <boost/bind.hpp>
 #include <stdexcept>
 
@@ -31,7 +32,7 @@ namespace BOOM{
 
 
     typedef PcrBetaConstraint PBC;
-    bool PBC::check(const Vec &b)const{
+    bool PBC::check(const Vector &b)const{
       uint b_sz = b.size();
       if(b_sz<2) return false;
       uint M = b_sz-2;
@@ -42,7 +43,7 @@ namespace BOOM{
       return bM == (M+1)*b0;  // factor of 'a' cancels
     }
 
-    void PBC::impose(Vec &b)const{
+    void PBC::impose(Vector &b)const{
       uint b_sz = b.size();
       assert(b_sz>=2);
       uint M = b_sz-2;
@@ -52,21 +53,21 @@ namespace BOOM{
 
       double ad0 = M==0 ? 0.0 : beta0 + (beta0 - betaM)/dM;
       if(ad0!=0.0){
-	b-= ad0;
-	b.back()+=ad0;
+        b-= ad0;
+        b.back()+=ad0;
       }
     }
 
-    Vec PBC::reduce(const Vec &b)const{
+    Vector PBC::reduce(const Vector &b)const{
       uint b_sz = b.size();
       assert(b_sz>=2);
-      Vec ans(b_sz-1);
+      Vector ans(b_sz-1);
       std::copy(b.begin()+1, b.end(), ans.begin());
       return ans;
     }
 
-    Vec PBC::expand(const Vec &b)const{
-      Vec ans(b.size()+1);
+    Vector PBC::expand(const Vector &b)const{
+      Vector ans(b.size()+1);
       std::copy(b.begin(), b.end(), ans.begin());
       uint M = b.size()-1;
       double dM = M;
@@ -77,24 +78,24 @@ namespace BOOM{
     //______________________________________________________________________
     typedef PcrDConstraint PDC;
 
-    bool PDC::check(const Vec &d)const{
+    bool PDC::check(const Vector &d)const{
       return(d[0]==0.0 && d.sum()==0.0);}
 
-    void PDC::impose(Vec &d)const{
+    void PDC::impose(Vector &d)const{
       double d0 = d[0];
       d-= d0;
       d.back()-= d.sum();
     }
 
-    Vec PDC::reduce(const Vec &d_full)const{
-      if(d_full.size()<=2) return Vec(0);
-      Vec ans(d_full.size()-2);
+    Vector PDC::reduce(const Vector &d_full)const{
+      if(d_full.size()<=2) return Vector(0);
+      Vector ans(d_full.size()-2);
       std::copy(d_full.begin()+1, d_full.end()-1, ans.begin());
       return ans;
     }
 
-    Vec PDC::expand(const Vec &d_min)const{
-      Vec ans(d_min.size()+2);
+    Vector PDC::expand(const Vector &d_min)const{
+      Vector ans(d_min.size()+2);
       ans[0] = 0.0;
       std::copy(d_min.begin(), d_min.end(), ans.begin()+1);
       ans.back() = -d_min.sum();
@@ -145,65 +146,65 @@ namespace BOOM{
     // constructors
 
     Ptr<CVP> make_d_uint(uint Maxscore, bool id_d0);
-    Ptr<CVP> make_d_vec(const Vec &d, bool id_d0);
+    Ptr<CVP> make_d_vec(const Vector &d, bool id_d0);
 
     Ptr<CVP> make_d_uint(uint Maxscore, bool id_d0){
-      Vec d(Maxscore+1, 0.0);
+      Vector d(Maxscore+1, 0.0);
       return make_d_vec(d, id_d0);
     }
 
-    Ptr<CVP> make_d_vec(const Vec &d, bool id_d0){
+    Ptr<CVP> make_d_vec(const Vector &d, bool id_d0){
       if(id_d0) return new CVP(d, new PcrDConstraint);
       return new CVP(d, new SumConstraint(0.0));
     }
 
 
     PCR::PartialCreditModel(const string &Id, uint Mscore, uint which_sub,
-			    uint Nscales, const string &Name, bool id_d0)
+                            uint Nscales, const string &Name, bool id_d0)
       : Item(Id, Mscore, which_sub, Nscales, Name),
-	ParamPolicy(new UnivParams(1.0), new UnivParams(0.0),
-		    make_d_uint(Mscore, id_d0)),
-	PriorPolicy(),
-	b_(Mscore+2),
-	eta_(Mscore+1),
-	X_(Mscore+1, Mscore+2),
-	d0_is_fixed(true),
-	which_subscale_(which_sub)
+        ParamPolicy(new UnivParams(1.0), new UnivParams(0.0),
+                    make_d_uint(Mscore, id_d0)),
+        PriorPolicy(),
+        b_(Mscore+2),
+        eta_(Mscore+1),
+        X_(Mscore+1, Mscore+2),
+        d0_is_fixed(true),
+        which_subscale_(which_sub)
     {
       setup();
     }
 
     PCR::PartialCreditModel(const string &Id, uint Mscore, uint which_sub,
-			    uint Nscales, double a, double b, const Vec &d,
-			    const string &Name, bool id_d0)
+                            uint Nscales, double a, double b, const Vector &d,
+                            const string &Name, bool id_d0)
       : Item(Id, Mscore, which_sub, Nscales, Name),
-	ParamPolicy(new UnivParams(a), new UnivParams(b),
-		    make_d_vec(d, id_d0)),
-	PriorPolicy(),
-	b_(Mscore+2),
-	eta_(Mscore+1),
-	X_(Mscore+1, Mscore+2),
-	d0_is_fixed(true),
-	which_subscale_(which_sub)
+        ParamPolicy(new UnivParams(a), new UnivParams(b),
+                    make_d_vec(d, id_d0)),
+        PriorPolicy(),
+        b_(Mscore+2),
+        eta_(Mscore+1),
+        X_(Mscore+1, Mscore+2),
+        d0_is_fixed(true),
+        which_subscale_(which_sub)
     {
       setup();
     }
 
     PCR::PartialCreditModel(const PCR &rhs)
       : Model(rhs),
-	Item(rhs),
-	ParamPolicy(rhs),
-	PriorPolicy(rhs),
-	b_(rhs.b_),
-	eta_(rhs.eta_),
-	X_(rhs.X_),
-	d0_is_fixed(rhs.d0_is_fixed),
-	beta_(rhs.beta_->clone()),
-	beta_current(rhs.beta_current),
-	a_current(rhs.a_current),
-	b_current(rhs.b_current),
-	d_current(rhs.d_current),
-	which_subscale_(rhs.which_subscale_)
+        Item(rhs),
+        ParamPolicy(rhs),
+        PriorPolicy(rhs),
+        b_(rhs.b_),
+        eta_(rhs.eta_),
+        X_(rhs.X_),
+        d0_is_fixed(rhs.d0_is_fixed),
+        beta_(rhs.beta_->clone()),
+        beta_current(rhs.beta_current),
+        a_current(rhs.a_current),
+        b_current(rhs.b_current),
+        d_current(rhs.d_current),
+        which_subscale_(rhs.which_subscale_)
     {
       //      setup();
       setup_aliases();
@@ -248,11 +249,11 @@ namespace BOOM{
       return beta_;
     }
 
-    ParamVec PCR::t(){
+    ParamVector PCR::t(){
       sync_params();
       return ParamPolicy::t();}
 
-    const ParamVec PCR::t()const{
+    const ParamVector PCR::t()const{
       sync_params();
       return ParamPolicy::t();}
 
@@ -260,11 +261,11 @@ namespace BOOM{
     double PCR::b()const{ return B_prm()->value();}
 
     double PCR::d(uint m)const{ return d()[m]; }
-    const Vec & PCR::d()const{ return D_prm()->value(); }
+    const Vector & PCR::d()const{ return D_prm()->value(); }
 
     void PCR::set_a(double A){ A_prm()->set(A); a_current=true;}
     void PCR::set_b(double B){ B_prm()->set(B); b_current=true;}
-    void PCR::set_d(const Vec &D){
+    void PCR::set_d(const Vector &D){
       assert(D.size()==maxscore()+1);  // ==nlevels
       D_prm()->set(D);
       d_current=true;
@@ -277,51 +278,51 @@ namespace BOOM{
     void PCR::initialize_params(){
       set_a(1.0);
       set_b(1.0);
-      Vec h = response_histogram();
-      Vec b = beta();
+      Vector h = response_histogram();
+      Vector b = beta();
       b[0] = 0;
       b.back()=0.001;     // a should not be zero
       for(uint i=1; i<h.size(); ++i)
-	b[i] = log(h[i]/h[0]);
+        b[i] = log(h[i]/h[0]);
       set_beta(b);
     }
 
     void PCR::sync_params()const{
       if(beta_current){
-	if(!(a_current && b_current && d_current)) fill_abd();
+        if(!(a_current && b_current && d_current)) fill_abd();
       }else if(a_current && b_current && d_current){
-	if(!beta_current) fill_beta();
+        if(!beta_current) fill_beta();
       }else{
-	throw_exception<std::runtime_error>("No current params in sync_params");
+        report_error("No current params in sync_params");
       }
     }
 
-    const Vec & PCR::beta()const{ return Beta_prm()->value();}
+    const Vector & PCR::beta()const{ return Beta_prm()->value();}
 
-    void PCR::set_beta(const Vec &b){
+    void PCR::set_beta(const Vector &b){
       beta_->set(b);
       beta_current=true;
     }
 
-    const Vec & PCR::fill_eta(const Vec & Theta)const{
+    const Vector & PCR::fill_eta(const Vector & Theta)const{
       eta_ = X(Theta)*beta();
       return eta_;
     }
 
-    const Mat & PCR::X(const Vec &Theta)const{
+    const Matrix & PCR::X(const Vector &Theta)const{
       return X(Theta[which_subscale()]); }
 
-    const Mat & PCR::X(double theta)const{
+    const Matrix & PCR::X(double theta)const{
       VectorView v(X_.last_col());
       v[0] = theta;
       for(uint i=1; i<v.size(); ++i) v[i] = v[i-1]+theta;
       return X_;
     }
 
-    double PCR::response_prob(Response r, const Vec &Theta, bool logsc)const{
+    double PCR::response_prob(Response r, const Vector &Theta, bool logsc)const{
       return response_prob(r->value(), Theta, logsc);}
 
-    double PCR::response_prob(uint r, const Vec & Theta, bool logsc)const{
+    double PCR::response_prob(uint r, const Vector & Theta, bool logsc)const{
       fill_eta(Theta);
       double lognc = lse(eta_);
       double ans = eta_[r] - lognc;
@@ -331,8 +332,8 @@ namespace BOOM{
     std::pair<double, double> PCR::theta_moments()const{
       double mean(0), var(0), n(0);
       for_each(subjects().begin(), subjects().end(),
-	       boost::bind(&PCR::increment_theta_moments, this, _1,
-			   boost::ref(mean), boost::ref(var), boost::ref(n)));
+               boost::bind(&PCR::increment_theta_moments, this, _1,
+                           boost::ref(mean), boost::ref(var), boost::ref(n)));
       if(n>0) mean/=n;
       var -= n*mean*mean;
       if(n>1) var/= n-1;
@@ -349,8 +350,8 @@ namespace BOOM{
 
     ostream & PCR::display_item_params(ostream &out, bool )const{
       out << a() << " "
-	  << b() << " "
-	  << d() << " ";
+          << b() << " "
+          << d() << " ";
       return out;
     }
 
@@ -362,7 +363,7 @@ namespace BOOM{
     void PCR::fill_beta(bool first_time)const{
       double a = first_time ? A_prm(false)->value() : this->a();
       double b = first_time ? B_prm(false)->value() : this->b();
-      const Vec &d(first_time ? D_prm(false)->value() : this->d());
+      const Vector &d(first_time ? D_prm(false)->value() : this->d());
 
       uint M = maxscore();
       b_[0] = a*(d[0]-b);
@@ -377,20 +378,20 @@ namespace BOOM{
 
     void PCR::fill_abd()const{
       uint M = maxscore();
-      const Vec &beta(this->beta());
+      const Vector &beta(this->beta());
       assert(beta.size()==M+2);
 
       double A = beta.back();
       double MA = (M+1)*A;
       double B = beta[M-1]/(-MA);
 
-      Vec D(M+1);
+      Vector D(M+1);
       D[0] = beta[0]+B;
 
       double last = 0;
       for(uint m = 0; m<D.size(); ++m){
-	D[m] = (beta[m]-last)/A  + B;
-	last = beta[m];
+        D[m] = (beta[m]-last)/A  + B;
+        last = beta[m];
       }
 
       a_prm->set(A);     // mutable pointers get around const-ness
@@ -406,7 +407,5 @@ namespace BOOM{
       d_current=true;
     }
 
-
-
   } // namespace IRT
 } // namespace BOOM
